#!/usr/bin/env perl
use Math::Trig;

# set the absolute paths
$PATH_SPICE_KERNEL = "/home/xxx/kernels";
$PATH_NIRS_BIN     = "/home/xxx/bin"; 
$PATH_NIRS_CAL     = "/home/xxx/nirs_calib";

$target = itokawa; # target name or id number (ex. itokawa, moon)

$KERNEL  = "$PATH_SPICE_KERNEL";
$GKERNEL = "$KERNEL/generic_kernels";
$IKERNEL = "$KERNEL/Itokawa";
$HKERNEL = "$KERNEL/HAYABUSA";
$ENV{'PATH_LSK'}           = "$GKERNEL/lsk/naif0009.tls";
$ENV{'PATH_PCK'}           = "$GKERNEL/pck/pck00008.tpc";
$ENV{'PATH_SPK'}           = "$GKERNEL/spk/de405.bsp";
$ENV{'PATH_ITOKAWA_FK'}    = "$HKERNEL/fk/itokawa_fixed.tf";
$ENV{'PATH_ITOKAWA_SPK'}   = "$IKERNEL/spk/itokawa_1989-2010.bsp";
$ENV{'PATH_HAYABUSA_FK'}   = "$HKERNEL/fk/HAYABUSA_HP.TF";
$ENV{'PATH_HAYABUSA_SCLK'} = "$HKERNEL/sclk/hayabusa.tsc";
#$ENV{'PATH_HAYABUSA_SPK'}  = "$HKERNEL/spk/hayabusa_20040516-20040531.bsp";
$ENV{'PATH_HAYABUSA_SPK'}  = "$HKERNEL/spk/hayabusa_itokawarendezvous_v01.bsp";

$ti2et = "$PATH_NIRS_BIN/ti2et";
$range = "$PATH_NIRS_BIN/range";

$nirs_vol2rad   = "$PATH_NIRS_CAL/nirs_vol2rad_als.tab";
$nirs_solar_spc = "$PATH_NIRS_CAL/nirs_solar_spc.tab";
@cal_info = `awk '{print \$1}' $nirs_vol2rad`;
@sol_info = `awk '{print \$1}' $nirs_solar_spc`;

$au = 1.49597870691E+08; # astronomical unit [km]

foreach $fits ( @ARGV ) {

    unless ( $fits =~ /\.fits$/ ) {
		print "Usage: command NIRS_FITS\n";
		exit; }

 	( $ti_end, $stack, $integ ) =
 		split ( /\s+/, `gethead -f $fits TIME STACK INTEG` );

	$et_end = `$ti2et $ti_end`; chomp ( $et_end );
	$et_str = $et_end - (( 65.536*2.0*( 2.0**$stack - 1.0 )) + $integ )*1.0E-03;
	$et_mid = ( $et_str + $et_end ) / 2.0;
 	( $rng_sn, $rng_sc ) = split ( /\s+/, `$range $et_mid $target` );

	@ave_info = `getpix -n 1 %.8e $fits 0 1`;
	@dev_info = `getpix -n 1 %.8e $fits 0 2`;

    $spc = $fits; $spc =~ s/fits/spc/; $spc =~ s/\_lvl1\.0//;

	open ( FILE, ">$spc" );
	printf ( FILE "# wl [nm], ref, err\n" );
	
     for ( $i = 0 ; $i < 64 ; $i++ ) {

         $vol_ave = $ave_info[$i]; chomp ( $vol_ave );
         $vol_dev = $dev_info[$i]; chomp ( $vol_dev );
         $vol2rad = $cal_info[$i]; chomp ( $vol2rad );
		 $solar   = $sol_info[$i]; chomp ( $solar );
		 
		 $ref = $vol_ave / $integ / $vol2rad / $solar * 1.0E+03 * pi
			 * (( $rng_sn / $au )**2.0 );
		 $err = $vol_dev / $integ / $vol2rad / $solar * 1.0E+03 * pi
			 * (( $rng_sn / $au )**2.0 );
		 
		 $wl = -23.56*( $i + 1 ) + 2271.44;
		 printf ( FILE "%7.2f  %13.6e  %13.6e\n", $wl, $ref, $err );
	 }
    close ( FILE );
	
    print "$fits -> $spc\n";
}
