#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <math.h>
#include <SpiceUsr.h>

void furnsh_kernels ( void );

int main ( int argc, char **argv ) {
  
  SpiceDouble  et, lt, sun[3], obs[3];
  
  if ( argc != 3 ) {
	fprintf ( stderr, "Return the ranges of sun & s/c from the target [km]\n" );
    fprintf ( stderr, "Usage:%s et target\n", argv[0] );
	fprintf ( stderr, "  et: ephemeris_time [s]\n" );
	fprintf ( stderr, "  target: name or id number (e.g., earth, 2025143)\n" );
    exit ( 0 ); }
  
  et = atof ( argv[1] );

  /* Furnish the required spice kernels */
  furnsh_kernels ();

  /* Get the positions of sun & s/c relative to the target */
  spkpos_c ( "SUN", et-lt, "J2000", "LT+S", argv[2], sun, &lt );
  spkpos_c ( argv[2], et, "J2000", "LT+S", "-130", obs, &lt );
  
  /* Put the ranges of sun & s/c from the target */
  printf ( "%.8e  %.8e\n", vnorm_c ( sun ), vnorm_c ( obs ) );

  return ( 0 );
}

void furnsh_kernels ( void ) {

  SpiceChar *LSK, *PCK, *SPK;
  SpiceChar *ITOKAWA_FK;
  SpiceChar *ITOKAWA_SPK;
  SpiceChar *HAYABUSA_FK;
  SpiceChar *HAYABUSA_SCLK;
  SpiceChar *HAYABUSA_SPK;
  
  LSK  = getenv ( "PATH_LSK" );
  PCK  = getenv ( "PATH_PCK" );
  SPK  = getenv ( "PATH_SPK" );
  ITOKAWA_FK   = getenv ( "PATH_ITOKAWA_FK" );
  ITOKAWA_SPK  = getenv ( "PATH_ITOKAWA_SPK" );
  HAYABUSA_FK  = getenv ( "PATH_HAYABUSA_FK" );
  HAYABUSA_SCLK= getenv ( "PATH_HAYABUSA_SCLK" );
  HAYABUSA_SPK = getenv ( "PATH_HAYABUSA_SPK" );
  
  furnsh_c ( LSK );
  furnsh_c ( PCK );
  furnsh_c ( SPK );
  furnsh_c ( ITOKAWA_FK );
  furnsh_c ( ITOKAWA_SPK );
  furnsh_c ( HAYABUSA_FK );
  furnsh_c ( HAYABUSA_SCLK );
  furnsh_c ( HAYABUSA_SPK );

}

